<?php
/**
 *
 * Copyright notice
 *
 * (c) sgalinski Internet Services (https://www.sgalinski.de)
 *
 * All rights reserved
 *
 * This script is part of the TYPO3 project. The TYPO3 project is
 * free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * The GNU General Public License can be found at
 * http://www.gnu.org/copyleft/gpl.html.
 *
 * This script is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * This copyright notice MUST APPEAR in all copies of the script!
 */

return call_user_func(
	function ($extKey, $table) {
		return [
			'ctrl' => [
				'title' => 'LLL:EXT:' . $extKey . '/Resources/Private/Language/locallang_db.xlf:' . $table . '_application',
				'label' => 'last_name',
				'label_alt' => 'job_title',
				'label_alt_force' => 1,
				'tstamp' => 'tstamp',
				'crdate' => 'crdate',
				'cruser_id' => 'cruser_id',
				'dividers2tabs' => TRUE,
				'searchFields' => 'job_id, job, job_title, company, gender, first_name, last_name, street, city, zip, country, nationality, education, birth_date, phone, mobile, email, message, cover_letter, certificate, cv',
				'versioningWS' => 2,
				'versioning_followPages' => TRUE,
				'origUid' => 't3_origuid',
				'languageField' => 'sys_language_uid',
				'transOrigPointerField' => 'l10n_parent',
				'transOrigDiffSourceField' => 'l10n_diffsource',
				'delete' => 'deleted',
				'enablecolumns' => [
					'disabled' => 'hidden',
					'starttime' => 'starttime',
					'endtime' => 'endtime',
				],
				'sortby' => 'sorting',
				'iconfile' => 'EXT:' . $extKey . '/Resources/Public/Icons/' . $table . '.svg'
			],
			'interface' => [
				'showRecordFieldList' => 'sys_language_uid, l10n_parent, l10n_diffsource, hidden, pid, job, job_id, job_title, company, department, experience_level, start_date, alternative_start_date,
				 company, task, qualification, description, contact, privacy_policy',
			],
			'types' => [
				'1' => [
					'showitem' => '--palette--;;sysLanguageAndHidden,job_id, job, job_title, company, gender, first_name, last_name, street, city, zip,
						country, nationality, education, birth_date, phone, mobile, email, message, privacy_policy, cover_letter, cv, certificate,
						div;;richtext[*]:rte_transform[mode=ts],
						--div--;LLL:EXT:frontend/Resources/Private/Language/locallang_ttc.xlf:tabs.access, starttime, endtime',
				],
			],
			'palettes' => [
				'sysLanguageAndHidden' => [
					'showitem' => 'sys_language_uid;;;;1-1-1, l10n_diffsource, hidden;;1, ',
					'canNotCollapse' => 1,
				]
			],
			'columns' => [
				'sys_language_uid' => [
					'exclude' => TRUE,
					'label' => 'LLL:EXT:core/Resources/Private/Language/locallang_general.xlf:LGL.language',
					'config' => [
						'type' => 'select',
						'special' => 'languages',
					],
				],
				'l10n_parent' => [
					'displayCond' => 'FIELD:sys_language_uid:>:0',
					'exclude' => TRUE,
					'label' => 'LLL:EXT:core/Resources/Private/Language/locallang_general.xlf:LGL.l18n_parent',
					'config' => [
						'type' => 'select',
						'items' => [
							['', 0],
						],
						'foreign_table' => $table . '_application',
						'foreign_table_where' => 'AND ' . $table . '_application.pid=###CURRENT_PID### AND ' . $table . '_application.sys_language_uid IN (-1,0)',
					],
				],
				'l10n_diffsource' => [
					'config' => [
						'type' => 'passthrough',
					],
				],
				't3ver_label' => [
					'label' => 'LLL:EXT:core/Resources/Private/Language/locallang_general.xlf:LGL.versionLabel',
					'config' => [
						'type' => 'input',
						'size' => 30,
						'max' => 255,
					]
				],
				'pid' => [
					'exclude' => FALSE,
					'label' => 'PID',
					'config' => [
						'type' => 'none',
					]
				],
				'hidden' => [
					'exclude' => TRUE,
					'label' => 'LLL:EXT:core/Resources/Private/Language/locallang_general.xlf:LGL.hidden',
					'config' => [
						'type' => 'check',
					],
				],
				'starttime' => [
					'exclude' => TRUE,
					'l10n_mode' => 'mergeIfNotBlank',
					'label' => 'LLL:EXT:core/Resources/Private/Language/locallang_general.xlf:LGL.starttime',
					'config' => [
						'type' => 'input',
						'size' => 13,
						'max' => 20,
						'eval' => 'datetime',
						'checkbox' => 0,
						'default' => 0,
						'range' => [
							'lower' => mktime(0, 0, 0, date('m'), date('d'), date('Y'))
						],
					],
				],
				'endtime' => [
					'exclude' => TRUE,
					'l10n_mode' => 'mergeIfNotBlank',
					'label' => 'LLL:EXT:core/Resources/Private/Language/locallang_general.xlf:LGL.endtime',
					'config' => [
						'type' => 'input',
						'size' => 13,
						'max' => 20,
						'eval' => 'datetime',
						'checkbox' => 0,
						'default' => 0,
						'range' => [
							'lower' => mktime(0, 0, 0, date('m'), date('d'), date('Y'))
						],
					],
				],
				'job_id' => [
					'exclude' => FALSE,
					'label' => 'LLL:EXT:' . $extKey . '/Resources/Private/Language/locallang_db.xlf:' . $table . '_application.job_id',
					'config' => [
						'type' => 'input',
						'size' => 30,
						'eval' => 'trim'
					],
				],
				'job' => [
					'exclude' => FALSE,
					'label' => 'LLL:EXT:' . $extKey . '/Resources/Private/Language/locallang_db.xlf:' . $table . '_application.job',
					'config' => [
						'type' => 'select',
						'renderType' => 'selectSingle',
						'internal_type' => 'db',
						'foreign_table' => $table,
						'size' => 1,
						'maxitems' => 1,
						'multiple' => 0,
						'fieldControl' => [
							'editPopup' => [
								'disabled' => FALSE,
							],
							'addRecord' => [
								'disabled' => FALSE,
							]
						],
					]
				],
				'job_title' => [
					'exclude' => FALSE,
					'label' => 'LLL:EXT:' . $extKey . '/Resources/Private/Language/locallang_db.xlf:' . $table . '_application.job_title',
					'config' => [
						'type' => 'input',
						'size' => 100,
						'eval' => 'trim'
					],
				],
				'company' => [
					'exclude' => FALSE,
					'label' => 'LLL:EXT:' . $extKey . '/Resources/Private/Language/locallang_db.xlf:' . $table . '.company',
					'config' => [
						'type' => 'select',
						'eval' => 'required',
						'renderType' => 'selectSingle',
						'internal_type' => 'db',
						'foreign_table' => 'tx_sgjobs_domain_model_company',
						'size' => 1,
						'maxitems' => 1,
						'multiple' => 0,
						'fieldControl' => [
							'editPopup' => [
								'disabled' => FALSE,
							],
							'addRecord' => [
								'disabled' => FALSE,
							]
						],
					]
				],
				'gender' => [
					'exclude' => FALSE,
					'label' => 'LLL:EXT:' . $extKey . '/Resources/Private/Language/locallang_db.xlf:' . $table . '_application.gender',
					'config' => [
						'type' => 'input',
						'size' => 30,
						'eval' => 'trim'
					],
				],
				'first_name' => [
					'exclude' => FALSE,
					'label' => 'LLL:EXT:' . $extKey . '/Resources/Private/Language/locallang_db.xlf:' . $table . '_application.first_name',
					'config' => [
						'type' => 'input',
						'size' => 30,
						'eval' => 'trim, required'
					],
				],
				'last_name' => [
					'exclude' => FALSE,
					'label' => 'LLL:EXT:' . $extKey . '/Resources/Private/Language/locallang_db.xlf:' . $table . '_application.last_name',
					'config' => [
						'type' => 'input',
						'size' => 30,
						'eval' => 'trim, required'
					],
				],
				'street' => [
					'exclude' => FALSE,
					'label' => 'LLL:EXT:' . $extKey . '/Resources/Private/Language/locallang_db.xlf:' . $table . '_application.street',
					'config' => [
						'type' => 'input',
						'size' => 30,
						'eval' => 'trim, required'
					],
				],
				'city' => [
					'exclude' => FALSE,
					'label' => 'LLL:EXT:' . $extKey . '/Resources/Private/Language/locallang_db.xlf:' . $table . '_application.city',
					'config' => [
						'type' => 'input',
						'size' => 30,
						'eval' => 'trim, required'
					],
				],
				'zip' => [
					'exclude' => FALSE,
					'label' => 'LLL:EXT:' . $extKey . '/Resources/Private/Language/locallang_db.xlf:' . $table . '_application.zip',
					'config' => [
						'type' => 'input',
						'size' => 30,
						'eval' => 'trim, required'
					],
				],
				'country' => [
					'exclude' => TRUE,
					'label' => 'LLL:EXT:' . $extKey . '/Resources/Private/Language/locallang_db.xlf:' . $table . '_application.country',
					'config' => [
						'type' => 'input',
						'size' => 30,
						'eval' => 'trim, required'
					],
				],
				'nationality' => [
					'exclude' => FALSE,
					'label' => 'LLL:EXT:' . $extKey . '/Resources/Private/Language/locallang_db.xlf:' . $table . '_application.nationality',
					'config' => [
						'type' => 'input',
						'size' => 30,
						'eval' => 'trim, required'
					],
				],
				'education' => [
					'exclude' => FALSE,
					'label' => 'LLL:EXT:' . $extKey . '/Resources/Private/Language/locallang_db.xlf:' . $table . '_application.education',
					'config' => [
						'type' => 'input',
						'size' => 30,
						'eval' => 'trim, required'
					],
				],
				'birth_date' => [
					'exclude' => TRUE,
					'label' => 'LLL:EXT:' . $extKey . '/Resources/Private/Language/locallang_db.xlf:' . $table . '_application.birth_date',
					'config' => [
						'type' => 'input',
						'size' => 30,
						'eval' => 'trim'
					],
				],
				'phone' => [
					'exclude' => FALSE,
					'label' => 'LLL:EXT:' . $extKey . '/Resources/Private/Language/locallang_db.xlf:' . $table . '_application.phone',
					'config' => [
						'type' => 'input',
						'size' => 30,
						'eval' => 'trim, required'
					],
				],
				'mobile' => [
					'exclude' => FALSE,
					'label' => 'LLL:EXT:' . $extKey . '/Resources/Private/Language/locallang_db.xlf:' . $table . '_application.mobile',
					'config' => [
						'type' => 'input',
						'size' => 30,
						'eval' => 'trim'
					],
				],
				'email' => [
					'exclude' => FALSE,
					'label' => 'LLL:EXT:' . $extKey . '/Resources/Private/Language/locallang_db.xlf:' . $table . '_application.email',
					'config' => [
						'type' => 'input',
						'size' => 30,
						'eval' => 'trim, required'
					],
				],
				'message' => [
					'exclude' => FALSE,
					'label' => 'LLL:EXT:' . $extKey . '/Resources/Private/Language/locallang_db.xlf:' . $table . '_application.message',
					'config' => [
						'type' => 'text',
						'cols' => 40,
						'rows' => 10
					],
				],
				'cover_letter' => [
					'exclude' => FALSE,
					'label' => 'LLL:EXT:' . $extKey . '/Resources/Private/Language/locallang_db.xlf:' . $table . '_application.cover_letter',
					'config' => \TYPO3\CMS\Core\Utility\ExtensionManagementUtility::getFileFieldTCAConfig(
						'cover_letter',
						['maxitems' => 1, 'minitems' => 1],
						'pdf'
					),
				],
				'certificate' => [
					'exclude' => FALSE,
					'label' => 'LLL:EXT:' . $extKey . '/Resources/Private/Language/locallang_db.xlf:' . $table . '_application.certificate',
					'config' => \TYPO3\CMS\Core\Utility\ExtensionManagementUtility::getFileFieldTCAConfig(
						'certificate',
						['maxitems' => 1, 'minitems' => 1],
						'pdf'
					),
				],
				'cv' => [
					'exclude' => FALSE,
					'label' => 'LLL:EXT:' . $extKey . '/Resources/Private/Language/locallang_db.xlf:' . $table . '_application.cv',
					'config' => \TYPO3\CMS\Core\Utility\ExtensionManagementUtility::getFileFieldTCAConfig(
						'cv',
						['maxitems' => 1, 'minitems' => 1],
						'pdf'
					),
				],
				'privacy_policy' => [
					'exclude' => FALSE,
					'label' => 'LLL:EXT:' . $extKey . '/Resources/Private/Language/locallang_db.xlf:' . $table . '_application.privacy_policy',
					'config' => [
						'type' => 'check',
						'default' => 0
					]
				]
			],
		];
	}, 'sg_jobs', 'tx_sgjobs_domain_model_job'
);

